@@ -27,7 +27,7 @@ HTTP_URL = "http://www.archipelagos-labs.com"
 HTTP_PORT = 6725
 
 
-# CLasses and functions
+# Classes and functions
 
 class PlatformError(Exception):
     """
@@ -482,13 +482,17 @@ class Archipelagos:
             raise ValueError("An unrecognised type of request has been specified")
 
     @staticmethod
-    def _get_pandas_data_frame(response: Any) -> pd.DataFrame:
+    def _get_pandas_data_frame(response: Any,
+                               features: List[str] = None) -> pd.DataFrame:
         """
         Builds a Pandas Data Frame from a response.
 
         :param response: The response received by the platform.
         :type response: Any
 
+        :param features: The (optional) list of features, or None.
+        :type features: List[str] or None
+
         :return: The data in response as a Pandas Data Frame.
         :rtype: pd.DataFrame
         """
@@ -498,30 +502,36 @@ class Archipelagos:
             else:
                 # Process the data in the response object
 
-                features = response.data.metadata.features
+                features_returned = response.data.metadata.features
                 data = {}
 
                 for date_time, feature_map_list in response.data.data.data:
                     if len(feature_map_list) > 1:
-                        raise ValueError(
-                            'There is more than one set of features for the date/time {}'.format(date_time))
+                        raise ValueError('There is more than one set of features for the date/time {}'.format(date_time))
 
                     elif len(feature_map_list) == 1:
-                        feature_values = [None] * len(features)
                         feature_map = feature_map_list[0]
 
-                        for i, feature_value in enumerate(features):
-                            feature_values[i] = feature_map.get(feature_value, None)
+                        if features is not None:
+                            feature_values = [None] * len(features)
+
+                            for i, feature_value in enumerate(features):
+                                feature_values[i] = feature_map.get(feature_value, None)
+                        else:
+                            feature_values = [None] * len(features_returned)
+
+                            for i, feature_value in enumerate(features_returned):
+                                feature_values[i] = feature_map.get(feature_value, None)
 
                         if date_time in data:
-                            raise ValueError(
-                                'There is more than one set of features for the date/time {}'.format(date_time))
+                            raise ValueError('There is more than one set of features for the date/time {}'.format(date_time))
                         else:
                             data[date_time] = feature_values
                     else:
                         data[date_time] = {}
 
-                return pd.DataFrame.from_dict(data, orient='index', columns=features)
+                columns = features if features is not None else list(features_returned.keys())
+                return pd.DataFrame.from_dict(data, orient='index', columns=columns)
 
         elif isinstance(response, CollectionResponse):
             if response.error_occurred:
@@ -566,13 +576,17 @@ class Archipelagos:
             raise ValueError('response is of an unsupported type')
 
     @staticmethod
-    def _get_numpy_array(response: Any) -> np.ndarray:
+    def _get_numpy_array(response: Any,
+                         features: List[str] = None) -> np.ndarray:
         """
         Builds a Numpy array from a response.
 
         :param response: The response received by the platform.
         :type response: Any
 
+        :param features: The (optional) list of features, or None.
+        :type features: List[str] or None
+
         :return: The data in response as a Numpy array.
         :rtype: np.ndarray or None
         """
@@ -583,8 +597,8 @@ class Archipelagos:
             else:
                 # Initialise the array to return
 
-                features = response.data.metadata.features
-                num_cols = len(features) + 1
+                features_returned = response.data.metadata.features
+                num_cols = len(features_returned) + 1
 
                 data = response.data.data.data
                 num_rows = np.sum([len(tup[1]) for tup in response.data.data.data])
@@ -602,8 +616,12 @@ class Archipelagos:
                             for feature_map in feature_map_list:
                                 numpy_array[row_num, 0] = date_time
 
-                                for col_num, feature_value in enumerate(features):
-                                    numpy_array[row_num, col_num + 1] = feature_map.get(feature_value, None)
+                                if features is not None:
+                                    for col_num, feature_value in enumerate(features):
+                                        numpy_array[row_num, col_num + 1] = feature_map.get(feature_value, None)
+                                else:
+                                    for col_num, feature_value in enumerate(features_returned):
+                                        numpy_array[row_num, col_num + 1] = feature_map.get(feature_value, None)
 
                                 row_num = row_num + 1
                         else:
@@ -678,7 +696,8 @@ class Archipelagos:
 
     @staticmethod
     def get_time_series(source: str,
-                        code: str, ts_id: str,
+                        code: str,
+                        ts_id: str,
                         start: Timestamp = None,
                         end: Timestamp = None,
                         features: List[str] = None,
@@ -706,7 +725,7 @@ class Archipelagos:
         :type end: Timestamp
 
         :param features: The (optional) list of features, or None.
-        :type features: List[str]
+        :type features: List[str] or None
 
         :param max_size: The (optional) maximum number of items that can be returned, or -1 if there should be no limit.
         :type max_size: int
@@ -739,9 +758,9 @@ class Archipelagos:
                 # Inspect the result and return the appropriate type of object
 
                 if return_pandas:
-                    return Archipelagos._get_pandas_data_frame(response)
+                    return Archipelagos._get_pandas_data_frame(response, features)
                 elif return_numpy:
-                    return Archipelagos._get_numpy_array(response)
+                    return Archipelagos._get_numpy_array(response, features)
                 else:
                     return None
             else:
