@@ -56,16 +56,17 @@ class Frequency(IntEnum):
     The different frequencies that data can occur.
     """
     NONE = 0
-    FIFTEEN_MINUTES = 1
-    THIRTY_MINUTES = 2
-    HOURLY = 3
-    DAILY = 4
-    WEEKLY = 5
-    MONTHLY = 6
-    QUARTERLY = 7
-    ANNUAL = 8
-    BIANNUAL = 9
-    IRREGULAR = 10
+    FIVE_MINUTES = 1
+    FIFTEEN_MINUTES = 2
+    THIRTY_MINUTES = 3
+    HOURLY = 4
+    DAILY = 5
+    WEEKLY = 6
+    MONTHLY = 7
+    QUARTERLY = 8
+    ANNUAL = 9
+    BIANNUAL = 10
+    IRREGULAR = 11
 
 
 def is_valid_token(token: str or None) -> bool:
@@ -188,6 +189,22 @@ def get_yyyy_mm_dd_hh_mm_ss_n(dt: datetime or Timestamp = None) -> str:
         return dt.strftime("%Y-%m-%dT%H:%M:%S.%f") + "000"
 
 
+def get_yyyy_mm_dd_hh_mm_ss(dt: datetime or Timestamp = None) -> str:
+    """
+    Returns a string representing a date in YYYY-MM-DDTHH:MM:SS format.
+
+    :param dt: The date/time.
+    :type dt: datetime or Timestamp
+
+    :return: Representing date in YYYY-MM-DDTHH:MM:SS.n format, or "" if dt was None.
+    :rtype: str
+    """
+    if dt is None:
+        return ""
+    else:
+        return dt.strftime("%Y-%m-%dT%H:%M:%S")
+
+
 def get_list(items: List[str]) -> str:
     """
     Generates a str containing a comma separate list from a List of str.
@@ -622,3 +639,31 @@ class DataType(Enum):
     TIME_SERIES = 0
     COLLECTION = 1
     FILE_STORE = 2
+
+
+class DataProperties:
+    """
+    The (optional) properties that a dataset (time-series, collection, file store...) may have.
+    """
+    WEBSITE = 'Website'
+    URI = 'URI'
+    LICENCE = 'Licence'
+    LICENCE_URL = 'Licence-URL'
+    INGESTED = 'Ingested'
+    COPYRIGHT = 'Copyright'
+    COPYRIGHT_URL = 'Copyright-URL'
+    LONGITUDE = 'Longitude'
+    LATITUDE = 'Latitude'
+
+
+class DataLicence:
+    """
+    The different licences that may be associated with datasets.
+    """
+    FREE_LICENCE = 'Free for personal and commercial use'
+    APACHE_2_LICENCE = 'Apache License, Version 2.0'
+    APACHE_2_LICENCE_URL = 'https://www.apache.org/licenses/LICENSE-2.0'
+    MIT_LICENCE = 'MIT License'
+    MIT_LICENCE_URL = 'http://opensource.org/licenses/MIT'
+    CREATIVE_COMMONS_4_LICENCE = 'Creative Commons Attribution 4.0 International License'
+    CREATIVE_COMMONS_4_LICENCE_URL = 'https://creativecommons.org/licenses/by/4.0'
