@@ -38,7 +38,7 @@ class CollectionMetadata:
                  properties: Dict[str, str],
                  premium: bool,
                  created: Timestamp,
-                 edited: Timestamp,
+                 edited: Timestamp = None,
                  refreshed: Timestamp = None):
         """
         All parameters should be supplied unless deserializing an object.
@@ -74,7 +74,7 @@ class CollectionMetadata:
         :type created: Timestamp
 
         :param edited: When (in UTC) the metadata for the collection was last edited.
-        :type edited: Timestamp
+        :type edited: Timestamp or None
 
         :param refreshed: When (in UTC) the data in the collection was last refreshed; can be None if no data has yet been entered.
         :type refreshed: Timestamp
@@ -138,7 +138,9 @@ class CollectionMetadata:
         if not isinstance(created, Timestamp):
             raise ValueError("created is not a valid Timestamp")
 
-        if not isinstance(edited, Timestamp):
+        if edited is None:
+            edited = created
+        elif not isinstance(edited, Timestamp):
             raise ValueError("edited is not a valid Timestamp")
 
         if edited < created:
