@@ -13,7 +13,7 @@ from archipelagos.common.protobuf.common.data.filestore import FileMetadataRespo
 from archipelagos.common.protobuf.common.data.filestore import FileMetadataRequest_pb2
 from archipelagos.common.protobuf.common.data.filestore import FileStoreMetadata_pb2, FileMetadata_pb2
 from archipelagos.common.protobuf.common import Timestamp_pb2
-from archipelagos.common.data import PYTHON_CLIENT
+from archipelagos.common.platform import ClientType
 
 from archipelagos.common.data import is_valid_token
 
@@ -716,6 +716,7 @@ class FileStoreMetadataRequest:
         self._source = source
         self._code = code
         self._fs_id = fs_id
+        self._client_type = ClientType.PYTHON_CLIENT
 
     @property
     def api_key(self) -> str:
@@ -774,6 +775,16 @@ class FileStoreMetadataRequest:
         """
         return self._fs_id
 
+    @property
+    def client_type(self) -> str:
+        """
+        Returns the type of client that sent the request.
+
+        :return: The type of client that sent the request.
+        :rtype: str
+        """
+        return self._client_type
+
     @staticmethod
     def deserialize(serialized: bytes) -> FileStoreMetadataRequest:
         """
@@ -812,6 +823,7 @@ class FileStoreMetadataRequest:
         self._source = metadata_request.source
         self._code = metadata_request.code
         self._fs_id = metadata_request.id
+        self._client_type = metadata_request.clientType
 
     def _write_proto_object(self) -> FileStoreMetadataRequest_pb2.FileStoreMetadataRequest:
         """
@@ -825,7 +837,7 @@ class FileStoreMetadataRequest:
         request.source = self._source
         request.code = self._code
         request.id = self._fs_id
-        request.clientType = PYTHON_CLIENT
+        request.clientType = self._client_type
 
         return request
 
@@ -1065,6 +1077,7 @@ class FileStoreRequest:
         self._code = code
         self._fs_id = fs_id
         self._name = name
+        self._client_type = ClientType.PYTHON_CLIENT
 
     @property
     def api_key(self) -> str or None:
@@ -1129,6 +1142,16 @@ class FileStoreRequest:
         """
         return self._name
 
+    @property
+    def client_type(self) -> str:
+        """
+        Returns the type of client that sent the request.
+
+        :return: The type of client that sent the request.
+        :rtype: str
+        """
+        return self._client_type
+
     @staticmethod
     def deserialize(serialized: bytes) -> FileStoreRequest:
         """
@@ -1168,6 +1191,7 @@ class FileStoreRequest:
         self._code = request.code
         self._fs_id = request.id
         self._name = request.name
+        self._client_type = request.clientType
 
     def _write_proto_object(self) -> FileStoreRequest_pb2.FileStoreRequest:
         """
@@ -1182,7 +1206,7 @@ class FileStoreRequest:
         request.code = self._code
         request.id = self._fs_id
         request.name = self._name
-        request.clientType = PYTHON_CLIENT
+        request.clientType = self._client_type
 
         return request
 
@@ -1445,6 +1469,7 @@ class FileMetadataRequest:
         self._code = code
         self._fs_id = fs_id
         self._pattern = pattern
+        self._client_type = ClientType.PYTHON_CLIENT
 
     @property
     def api_key(self) -> str:
@@ -1512,6 +1537,16 @@ class FileMetadataRequest:
         """
         return self._pattern
 
+    @property
+    def client_type(self) -> str:
+        """
+        Returns the type of client that sent the request.
+
+        :return: The type of client that sent the request.
+        :rtype: str
+        """
+        return self._client_type
+
     @staticmethod
     def deserialize(serialized: bytes) -> FileMetadataRequest:
         """
@@ -1552,6 +1587,7 @@ class FileMetadataRequest:
         self._source = metadata_request.source
         self._code = metadata_request.code
         self._fs_id = metadata_request.id
+        self._client_type = metadata_request.clientType
 
         if metadata_request.patternSet:
             self._pattern = metadata_request.pattern
@@ -1577,7 +1613,7 @@ class FileMetadataRequest:
             request.patternSet = True
             request.pattern = self._pattern
 
-        request.clientType = PYTHON_CLIENT
+        request.clientType = self._client_type
 
         return request
 
