@@ -344,9 +344,9 @@ class TimeSeriesMetadata:
     @property
     def oldest_date_time(self) -> Timestamp or None:
         """
-        Returns the oldest date/time in the associated time-series; can be null if the time-series is empty.
+        Returns the oldest date/time in the associated time-series; can be None if the time-series is empty.
 
-        :return: The oldest date/time in the associated time-series; can be null if the time-series is empty.
+        :return: The oldest date/time in the associated time-series; can be None if the time-series is empty.
         :rtype: Timestamp or None
         """
         return self._oldest_date_time
@@ -354,9 +354,9 @@ class TimeSeriesMetadata:
     @property
     def newest_date_time(self) -> Timestamp or None:
         """
-        Returns the newest date/time in the associated time-series; can be null if the time-series is empty.
+        Returns the newest date/time in the associated time-series; can be None if the time-series is empty.
 
-        :return: The newest date/time in the associated time-series; can be null if the time-series is empty.
+        :return: The newest date/time in the associated time-series; can be None if the time-series is empty.
         :rtype: Timestamp or None
         """
         return self._newest_date_time
@@ -1253,9 +1253,8 @@ class TimeSeriesMetadataResponse:
         :param serialized: The str produced by serialize().
         :type serialized: bytes
         """
-        byte_array = array.array('B', serialized)
         response = TimeSeriesMetadataResponse_pb2.TimeSeriesMetadataResponse()
-        response.ParseFromString(byte_array)
+        response.ParseFromString(serialized)
         self._read_proto_object(response)
 
     def _read_proto_object(self,
@@ -1275,7 +1274,7 @@ class TimeSeriesMetadataResponse:
         else:
             self._error_code = 0
             self._error_message = None
-            self._metadata = TimeSeriesMetadata("a", "a", "a", "", "", "", dict(), Frequency.NONE, dict(), False,Timestamp.now(), Timestamp.now())
+            self._metadata = TimeSeriesMetadata("a", "a", "a", "", "", "", dict(), Frequency.NONE, dict(), False, Timestamp.now(), Timestamp.now())
             self._metadata._read_proto_object(response.metadata)
 
     def _write_proto_object(self) -> TimeSeriesMetadataResponse_pb2.TimeSeriesMetadataResponse:
@@ -1806,9 +1805,8 @@ class TimeSeriesResponse:
         :param serialized: The str produced by serialize().
         :type serialized: bytes
         """
-        byte_array = array.array('B', serialized)
         response = TimeSeriesResponse_pb2.TimeSeriesResponse()
-        response.ParseFromString(byte_array)
+        response.ParseFromString(serialized)
         self._read_proto_object(response)
 
     def _read_proto_object(self,
